@@ -890,18 +890,17 @@ static int bindfs_readdir(const char *path, void *buf, fuse_fill_dir_t filler,
                 if (resolved) {
                     if (lstat(resolved, &st) == -1) {
                         result = -errno;
+                        free(resolved);
                         break;
                     }
                     free(resolved);
-                } else {
-                    result = -errno;
-                    break;
-                }
-            } else {
-                if (lstat(path_buf.ptr, &st) == -1) {
+                } else if (lstat(path_buf.ptr, &st) == -1) {
                     result = -errno;
                     break;
                 }
+            } else if (lstat(path_buf.ptr, &st) == -1) {
+                result = -errno;
+                break;
             }
 
             if (readdirplus) {
@@ -2900,6 +2899,19 @@ int main(int argc, char *argv[])
         free(tmp);
     }
 
+    /* OpenRC unmounts all filesystems with the "fuse" type when the network goes down (issue #72).
+
+       Because we set mntsrc as fsname to be consistent with "real" filesystems,
+       we need to add the subtype argument so that it doesn't mount with the "fuse" type.
+
+       Eg. "fuse.bindfs"
+     */
+#ifndef __FreeBSD__
+    char *tmp = sprintf_new("-osubtype=%s", my_basename(settings.progname));
+    fuse_opt_add_arg(&args, tmp);
+    free(tmp);
+#endif
+
     // With FUSE 3, we disable caches in bindfs_init
 #ifndef HAVE_FUSE_3
     /* We need to disable the attribute cache whenever two users
